import { Tooltip, Image } from 'antd';
import Filedetail from "@/components/Filedetail";
function getcolumns(setdrawer, valtype, itemId) {
    let common = [
        {
            title: '合同单号',
            dataIndex: 'contractNo',
            key: 'contractNo',
            formItemProps: { rules: [{ required: true, message: '此项为必填项' }] },
            colProps: { span: 8 },
            render: (_, row) => {
                return (
                    <a
                        className="table-cell"
                        onClick={() => {
                            setdrawer && setdrawer((s) => ({
                                ...s,
                                open: true,
                                item: row,
                                val: 'only',
                                title: '合同详情',
                                type: 'detail'
                            }));
                        }}
                    >
                        {row.contractNo}
                    </a>
                );
            }
        },
        {
            title: '客户',
            dataIndex: 'customerName',
            key: 'customerId',
            colProps: { span: 8 },
            formItemProps: { rules: [{ required: true, message: '此项为必填项' }] },
            valueType: 'select',
            options: { path: '/lease/umLeaseCustomer/getSelection', params: {} },
            fieldProps: {
                showSearch: true
            },
        },
        {
            title: '合同金额（元）',
            dataIndex: 'amount',
            key: 'amount',
            hideInSearch: true,
            hideInForm: true,
        },
        {
            title: '合同起租日',
            dataIndex: 'startLeaseDate',
            key: 'startLeaseDateList',
            hideInForm: true,
            valueType: 'dateRange'
        },
        {
            title: '本期应收回款',
            dataIndex: 'thisCollection',
            key: 'thisCollection',
            hideInSearch: true,
            hideInForm: true,
        },
        {
            title: '设备台数',
            dataIndex: 'equipmentNum',
            key: 'equipmentNum',
            hideInSearch: true,
            hideInForm: true,
            render: (_, row) => {
                return (
                    <a
                        className="table-cell"
                        onClick={() => {
                            setdrawer && setdrawer((s) => ({
                                ...s,
                                open: true,
                                item: row,
                                val: 'only',
                                title: '租赁设备',
                                type: 'device'
                            }));
                        }}
                    >
                        {row.equipmentNum}
                    </a>
                );
            }
        },
        {
            title: '去程运费',
            dataIndex: 'tripFreight',
            key: 'tripFreight',
            colProps: { span: 8 },
            valueType: 'digit',
            hideInSearch: true,
            hideInTable: true,
            precision: 2
        },
        {
            title: '去程运费承担方',
            dataIndex: 'tripBear',
            key: 'tripBear',
            hideInSearch: true,
            valueType: 'select',
            options: [
                { label: '客户', value: '1' },
                { label: '平台', value: '2' },
            ],
            colProps: { span: 8 },
            hideInTable: true,
        },
        {
            title: '回款设置（自然日）',
            dataIndex: 'collectionSet',
            key: 'collectionSet',
            valueType: 'digit',
            hideInSearch: true,
            formItemProps: { rules: [{ required: true, message: '此项为必填项' }] },
            colProps: { span: 8 },
            hideInTable: true
        },
        {
            title: '预警设置（自然日）',
            dataIndex: 'warnSet',
            key: 'warnSet',
            hideInSearch: true,
            formItemProps: { rules: [{ required: true, message: '此项为必填项' }] },
            colProps: { span: 8 },
            valueType: 'digit',
            hideInTable: true
        },
        {
            title: '合同租期（月）',
            dataIndex: 'tenancy',
            key: 'tenancy',
            formItemProps: { rules: [{ required: true, message: '此项为必填项' }] },
            colProps: { span: 8 },
            hideInSearch: true,
            valueType: 'digit',
            hideInTable: true,
            precision: 0
        },
        {
            title: '租赁设备',
            dataIndex: 'contractEquipmentList',
            key: 'contractEquipmentList',
            hideInSearch: true,
            valueType: 'formList',
            hideInTable: true,
            colProps: {
                xs: 24,
                sm: 24,
            },
            columns: [
                {
                    title: '设备',
                    dataIndex: 'equipmentName',
                    key: 'equipmentId',
                    valueType: 'select',
                    fieldProps: {
                        placeholder: '请选择',
                        showSearch: true
                    },
                    formItemProps: {
                        rules: [
                            {
                                required: true,
                                message: '此项为必填项',
                            },
                        ],
                    },
                    colProps: {
                        sm: 6,
                    },
                    options: {
                        path: '/lease/umLeaseLedger/queryLedgerSelectbox',
                        params: valtype == 'add' ? {} : { contractId: itemId },
                    },
                },
                {
                    title: '每期单价（元）',
                    dataIndex: 'unitPrice',
                    key: 'unitPrice',
                    valueType: 'digit',
                    precision: 2,
                    formItemProps: {
                        rules: [
                            {
                                required: true,
                                message: '此项为必填项',
                            },
                        ],
                    },
                    colProps: {
                        sm: 3,
                    },
                    min: 0.01
                },
                {
                    title: '智享价（元）',
                    dataIndex: 'zxPrice',
                    key: 'zxPrice',
                    valueType: 'digit',
                    precision: 2,
                    formItemProps: {
                        rules: [
                            {
                                required: true,
                                message: '此项为必填项',
                            },
                        ],
                    },
                    colProps: {
                        sm: 3,
                    },
                    min: 0.01
                },
                {
                    title: '返利金额（元）',
                    dataIndex: 'rebatePrice',
                    key: 'rebatePrice',
                    valueType: 'digit',
                    precision: 2,
                    formItemProps: {
                        rules: [
                            {
                                required: true,
                                message: '此项为必填项',
                            },
                        ],
                    },
                    colProps: {
                        sm: 3,
                    },
                    fieldProps: {
                        disabled: true
                    },
                    min: 0.00
                },
                {
                    title: '押金（元）',
                    dataIndex: 'deposit',
                    key: 'deposit',
                    valueType: 'digit',
                    precision: 2,
                    formItemProps: {
                        rules: [
                            {
                                required: true,
                                message: '此项为必填项',
                            },
                        ],
                    },
                    colProps: {
                        sm: 3,
                    },
                    min: 0.01
                },
                {
                    title: '备注',
                    dataIndex: 'remark',
                    key: 'remark',
                    colProps: {
                        sm: 6,
                    },
                }
            ],
            formItemProps: { rules: [{ required: true, message: '此项为必填项' }] },
            min: 1
        },
        {
            title: '营销区域',
            dataIndex: 'marketRegion',
            key: 'marketRegion',
            hideInSearch: true,
            colProps: { span: 8 },
            hideInTable: true,
        },
        {
            title: '智享店',
            dataIndex: 'zxstore',
            key: 'zxstore',
            colProps: { span: 8 },
            hideInSearch: true,
            hideInTable: true,
        },
        {
            title: '登记日期',
            dataIndex: 'registrationDate',
            key: 'registrationDate',
            colProps: { span: 8 },
            hideInSearch: true,
            hideInTable: true,
            valueType: 'date',
        },
        {
            title: '承接合同编号',
            dataIndex: 'undertakingNo',
            key: 'undertakingId',
            colProps: { span: 8 },
            hideInSearch: true,
            hideInTable: true,
            valueType: 'select',
            options: { path: '/lease/umContract/querySelect', params: { id: valtype == 'edit' ? itemId : '' } },
        },
        {
            title: '合同负责人',
            dataIndex: 'head',
            key: 'head',
            hideInSearch: true,
            hideInTable: true,
            colProps: { span: 8 },
        },
        {
            title: '合同上传（最多5个）',
            dataIndex: 'contractFileList',
            key: 'contractFileList',
            hideInSearch: true,
            hideInTable: false,
            valueType: 'uploadBtn',
            span: 3,
            fieldProps: {
                limit: 5,
            },
            colProps: { span: 24 },
            render: (_, row) => {
                return <Filedetail files={valtype == 'only' ? row?.['contractFileList'] : (row?.['contractFileList']?.[0] ? [row?.['contractFileList']?.[0]] : [])} />
            }
        }
    ];
    return [
        {
            tab: '未完成',
            key: '1',
            columns: [
                ...common,
                {
                    title: '状态',
                    dataIndex: 'statusName',
                    key: 'status',
                    options: [
                        {
                            label: '未开始',
                            value: 1
                        }, {
                            label: '进行中',
                            value: 2
                        }, {
                            label: '已到期',
                            value: 3
                        }, {
                            label: '待押金退还',
                            value: 4
                        },
                    ],
                    fieldProps: {
                        dropdownMatchSelectWidth: 150,
                    },
                    valueType: 'select',
                    hideInForm: true
                },
            ],
            pathconfig: {
                enableadd: true,
                add: '/lease/umContract/save',
                edit: '/lease/umContract/save',
                list: '/lease/umContract/queryIncomplete',
                delete: '/lease/umContract/delete',
                detail: '/lease/umContract/queryDetail',
            },
        },
        {
            tab: '已完成',
            key: '2',
            columns: [
                ...common,
                {
                    title: '状态',
                    dataIndex: 'statusName',
                    key: 'status',
                    options: [
                        {
                            label: '正常完成',
                            value: 5
                        }, {
                            label: '提前退租',
                            value: 6
                        },
                    ],
                    fieldProps: {
                        dropdownMatchSelectWidth: 150,
                    },
                    valueType: 'select',
                    hideInForm: true
                },
            ],
            pathconfig: {
                add: '',
                edit: '',
                list: '/lease/umContract/queryComplete',
                delete: '',
                detail: '/lease/umContract/queryDetail',
            },
        },
    ];
}
export default getcolumns;
